# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x97\x01\n\x0cLoginRequest\x12+\n\x05owner\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x86\x02\n\rLoginResponse\x12\x36\n\x07user_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07user_id\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04role\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x08owner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08owner_id\x12+\n\x05token\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x85\x05\n\x04User\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06source\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tuser_type\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tuser_type\x12,\n\x06mobile\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x65mail\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xc2\x01\n\x12ModifyUserPassword\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0cold_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cold_password\x12@\n\x0cnew_password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cnew_password\"f\n\x11UserGroupRelation\x12\x38\n\x08group_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08group_id\x12\x17\n\x05users\x18\x02 \x03(\x0b\x32\x08.v1.User\"\xfc\x03\n\tUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x08relation\x18\t \x01(\x0b\x32\x15.v1.UserGroupRelation\x12<\n\nuser_count\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nuser_count\"\xc1\x03\n\x0fModifyUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\radd_relations\x18\x07 \x01(\x0b\x32\x15.v1.UserGroupRelationR\radd_relations\x12\x41\n\x10remove_relations\x18\x08 \x01(\x0b\x32\x15.v1.UserGroupRelationR\x10remove_relations\"a\n\tPrincipal\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"I\n\nPrincipals\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.v1.Principal\x12\x1d\n\x06groups\x18\x02 \x03(\x0b\x32\r.v1.Principal\"\x9e\x01\n\x15StrategyResourceEntry\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf0\x01\n\x11StrategyResources\x12>\n\x0bstrategy_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bstrategy_id\x12-\n\nnamespaces\x18\x02 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12+\n\x08services\x18\x03 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12?\n\rconfig_groups\x18\x04 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\rconfig_groups\"\x8e\x04\n\x0c\x41uthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\"\n\nprincipals\x18\x03 \x01(\x0b\x32\x0e.v1.Principals\x12(\n\tresources\x18\x04 \x01(\x0b\x32\x15.v1.StrategyResources\x12\x1e\n\x06\x61\x63tion\x18\x05 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12\x46\n\x10\x64\x65\x66\x61ult_strategy\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x64\x65\x66\x61ult_strategy\"\xdc\x03\n\x12ModifyAuthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x0e\x61\x64\x64_principals\x18\x03 \x01(\x0b\x32\x0e.v1.PrincipalsR\x0e\x61\x64\x64_principals\x12<\n\x11remove_principals\x18\x04 \x01(\x0b\x32\x0e.v1.PrincipalsR\x11remove_principals\x12;\n\radd_resources\x18\x05 \x01(\x0b\x32\x15.v1.StrategyResourcesR\radd_resources\x12\x41\n\x10remove_resources\x18\x06 \x01(\x0b\x32\x15.v1.StrategyResourcesR\x10remove_resources\x12\x1e\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue*+\n\nAuthAction\x12\r\n\tONLY_READ\x10\x00\x12\x0e\n\nREAD_WRITE\x10\x01*>\n\x0cResourceType\x12\x0e\n\nNamespaces\x10\x00\x12\x0c\n\x08Services\x10\x01\x12\x10\n\x0c\x43onfigGroups\x10\x02\x42\x82\x01\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/securityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/security'
  _globals['_AUTHACTION']._serialized_start=3967
  _globals['_AUTHACTION']._serialized_end=4010
  _globals['_RESOURCETYPE']._serialized_start=4012
  _globals['_RESOURCETYPE']._serialized_end=4074
  _globals['_LOGINREQUEST']._serialized_start=51
  _globals['_LOGINREQUEST']._serialized_end=202
  _globals['_LOGINRESPONSE']._serialized_start=205
  _globals['_LOGINRESPONSE']._serialized_end=467
  _globals['_USER']._serialized_start=470
  _globals['_USER']._serialized_end=1115
  _globals['_MODIFYUSERPASSWORD']._serialized_start=1118
  _globals['_MODIFYUSERPASSWORD']._serialized_end=1312
  _globals['_USERGROUPRELATION']._serialized_start=1314
  _globals['_USERGROUPRELATION']._serialized_end=1416
  _globals['_USERGROUP']._serialized_start=1419
  _globals['_USERGROUP']._serialized_end=1927
  _globals['_MODIFYUSERGROUP']._serialized_start=1930
  _globals['_MODIFYUSERGROUP']._serialized_end=2379
  _globals['_PRINCIPAL']._serialized_start=2381
  _globals['_PRINCIPAL']._serialized_end=2478
  _globals['_PRINCIPALS']._serialized_start=2480
  _globals['_PRINCIPALS']._serialized_end=2553
  _globals['_STRATEGYRESOURCEENTRY']._serialized_start=2556
  _globals['_STRATEGYRESOURCEENTRY']._serialized_end=2714
  _globals['_STRATEGYRESOURCES']._serialized_start=2717
  _globals['_STRATEGYRESOURCES']._serialized_end=2957
  _globals['_AUTHSTRATEGY']._serialized_start=2960
  _globals['_AUTHSTRATEGY']._serialized_end=3486
  _globals['_MODIFYAUTHSTRATEGY']._serialized_start=3489
  _globals['_MODIFYAUTHSTRATEGY']._serialized_end=3965
# @@protoc_insertion_point(module_scope)



from ..service_manage import client_pb2 as _client_pb2
from ..service_manage import service_pb2 as _service_pb2
from ..service_manage import request_pb2 as _request_pb2
from ..service_manage import response_pb2 as _response_pb2
from ..service_manage import heartbeat_pb2 as _heartbeat_pb2
from ..service_manage import contract_pb2 as _contract_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x92\x01\n\x08Location\x12,\n\x06region\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04zone\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x63\x61mpus\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb0\x02\n\x0bMatchString\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.v1.MatchString.MatchStringType\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\nvalue_type\x18\x03 \x01(\x0e\x32\x19.v1.MatchString.ValueTypeR\nvalue_type\"V\n\x0fMatchStringType\x12\t\n\x05\x45XACT\x10\x00\x12\t\n\x05REGEX\x10\x01\x12\x0e\n\nNOT_EQUALS\x10\x02\x12\x06\n\x02IN\x10\x03\x12\n\n\x06NOT_IN\x10\x04\x12\t\n\x05RANGE\x10\x05\"2\n\tValueType\x12\x08\n\x04TEXT\x10\x00\x12\r\n\tPARAMETER\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xb1\x01\n\x07Summary\x12\x30\n\x13total_service_count\x18\x01 \x01(\rR\x13total_service_count\x12@\n\x1btotal_health_instance_count\x18\x02 \x01(\rR\x1btotal_health_instance_count\x12\x32\n\x14total_instance_count\x18\x03 \x01(\rR\x14total_instance_count\":\n\x0b\x43lientLabel\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchStringBy\n.com.tencent.polaris.specification.api.v1.modelB\nModelProtoZ;github.com/polarismesh/specification/source/go/api/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.tencent.polaris.specification.api.v1.modelB\nModelProtoZ;github.com/polarismesh/specification/source/go/api/v1/model'
  _globals['_LOCATION']._serialized_start=52
  _globals['_LOCATION']._serialized_end=198
  _globals['_MATCHSTRING']._serialized_start=201
  _globals['_MATCHSTRING']._serialized_end=505
  _globals['_MATCHSTRING_MATCHSTRINGTYPE']._serialized_start=367
  _globals['_MATCHSTRING_MATCHSTRINGTYPE']._serialized_end=453
  _globals['_MATCHSTRING_VALUETYPE']._serialized_start=455
  _globals['_MATCHSTRING_VALUETYPE']._serialized_end=505
  _globals['_STRINGLIST']._serialized_start=507
  _globals['_STRINGLIST']._serialized_end=535
  _globals['_SUMMARY']._serialized_start=538
  _globals['_SUMMARY']._serialized_end=715
  _globals['_CLIENTLABEL']._serialized_start=717
  _globals['_CLIENTLABEL']._serialized_end=775
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fault_detector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66\x61ult_detector.proto\x12\x02v1\x1a\x0bmodel.proto\"E\n\rFaultDetector\x12\"\n\x05rules\x18\x01 \x03(\x0b\x32\x13.v1.FaultDetectRule\x12\x10\n\x08revision\x18\x02 \x01(\t\"\xbd\x04\n\x0f\x46\x61ultDetectRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x10\n\x08revision\x18\x04 \x01(\t\x12\r\n\x05\x63time\x18\x05 \x01(\t\x12\r\n\x05mtime\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12>\n\x0etarget_service\x18\x15 \x01(\x0b\x32&.v1.FaultDetectRule.DestinationService\x12\x10\n\x08interval\x18\x16 \x01(\r\x12\x0f\n\x07timeout\x18\x17 \x01(\r\x12\x0c\n\x04port\x18\x18 \x01(\r\x12.\n\x08protocol\x18\x19 \x01(\x0e\x32\x1c.v1.FaultDetectRule.Protocol\x12+\n\x0bhttp_config\x18\x1a \x01(\x0b\x32\x16.v1.HttpProtocolConfig\x12)\n\ntcp_config\x18\x1b \x01(\x0b\x32\x15.v1.TcpProtocolConfig\x12)\n\nudp_config\x18\x1c \x01(\x0b\x32\x15.v1.UdpProtocolConfig\x1aY\n\x12\x44\x65stinationService\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x1f\n\x06method\x18\x03 \x01(\x0b\x32\x0f.v1.MatchString\"3\n\x08Protocol\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\x07\n\x03TCP\x10\x02\x12\x07\n\x03UDP\x10\x03J\x04\x08\x08\x10\x15\"\xa3\x01\n\x12HttpProtocolConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x35\n\x07headers\x18\x03 \x03(\x0b\x32$.v1.HttpProtocolConfig.MessageHeader\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x1a+\n\rMessageHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"2\n\x11TcpProtocolConfig\x12\x0c\n\x04send\x18\x01 \x01(\t\x12\x0f\n\x07receive\x18\x02 \x03(\t\"2\n\x11UdpProtocolConfig\x12\x0c\n\x04send\x18\x01 \x01(\t\x12\x0f\n\x07receive\x18\x02 \x03(\tB\x95\x01\n8com.tencent.polaris.specification.api.v1.fault.toleranceB\x12\x46\x61ultDetectorProtoZEgithub.com/polarismesh/specification/source/go/api/v1/fault_toleranceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fault_detector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8com.tencent.polaris.specification.api.v1.fault.toleranceB\022FaultDetectorProtoZEgithub.com/polarismesh/specification/source/go/api/v1/fault_tolerance'
  _globals['_FAULTDETECTOR']._serialized_start=41
  _globals['_FAULTDETECTOR']._serialized_end=110
  _globals['_FAULTDETECTRULE']._serialized_start=113
  _globals['_FAULTDETECTRULE']._serialized_end=686
  _globals['_FAULTDETECTRULE_DESTINATIONSERVICE']._serialized_start=538
  _globals['_FAULTDETECTRULE_DESTINATIONSERVICE']._serialized_end=627
  _globals['_FAULTDETECTRULE_PROTOCOL']._serialized_start=629
  _globals['_FAULTDETECTRULE_PROTOCOL']._serialized_end=680
  _globals['_HTTPPROTOCOLCONFIG']._serialized_start=689
  _globals['_HTTPPROTOCOLCONFIG']._serialized_end=852
  _globals['_HTTPPROTOCOLCONFIG_MESSAGEHEADER']._serialized_start=809
  _globals['_HTTPPROTOCOLCONFIG_MESSAGEHEADER']._serialized_end=852
  _globals['_TCPPROTOCOLCONFIG']._serialized_start=854
  _globals['_TCPPROTOCOLCONFIG']._serialized_end=904
  _globals['_UDPPROTOCOLCONFIG']._serialized_start=906
  _globals['_UDPPROTOCOLCONFIG']._serialized_end=956
# @@protoc_insertion_point(module_scope)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from ..model import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Level(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNKNOWN: _ClassVar[Level]
    SERVICE: _ClassVar[Level]
    METHOD: _ClassVar[Level]
    GROUP: _ClassVar[Level]
    INSTANCE: _ClassVar[Level]
UNKNOWN: Level
SERVICE: Level
METHOD: Level
GROUP: Level
INSTANCE: Level

class CircuitBreaker(_message.Message):
    __slots__ = ["id", "version", "name", "namespace", "service", "service_namespace", "inbounds", "outbounds", "token", "owners", "business", "department", "comment", "ctime", "mtime", "revision", "rules"]
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    INBOUNDS_FIELD_NUMBER: _ClassVar[int]
    OUTBOUNDS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    BUSINESS_FIELD_NUMBER: _ClassVar[int]
    DEPARTMENT_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    id: _wrappers_pb2.StringValue
    version: _wrappers_pb2.StringValue
    name: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    service: _wrappers_pb2.StringValue
    service_namespace: _wrappers_pb2.StringValue
    inbounds: _containers.RepeatedCompositeFieldContainer[CbRule]
    outbounds: _containers.RepeatedCompositeFieldContainer[CbRule]
    token: _wrappers_pb2.StringValue
    owners: _wrappers_pb2.StringValue
    business: _wrappers_pb2.StringValue
    department: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    revision: _wrappers_pb2.StringValue
    rules: _containers.RepeatedCompositeFieldContainer[CircuitBreakerRule]
    def __init__(self, id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., version: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., service_namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., inbounds: _Optional[_Iterable[_Union[CbRule, _Mapping]]] = ..., outbounds: _Optional[_Iterable[_Union[CbRule, _Mapping]]] = ..., token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owners: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., business: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., department: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., revision: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., rules: _Optional[_Iterable[_Union[CircuitBreakerRule, _Mapping]]] = ...) -> None: ...

class SourceMatcher(_message.Message):
    __slots__ = ["service", "namespace", "labels"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    labels: _containers.MessageMap[str, _model_pb2.MatchString]
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., labels: _Optional[_Mapping[str, _model_pb2.MatchString]] = ...) -> None: ...

class RecoverConfig(_message.Message):
    __slots__ = ["sleepWindow", "maxRetryAfterHalfOpen", "requestRateAfterHalfOpen", "successRateToClose", "requestCountAfterHalfOpen", "outlierDetectWhen"]
    class OutlierDetectWhen(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        NEVER: _ClassVar[RecoverConfig.OutlierDetectWhen]
        ON_RECOVER: _ClassVar[RecoverConfig.OutlierDetectWhen]
        ALWAYS: _ClassVar[RecoverConfig.OutlierDetectWhen]
    NEVER: RecoverConfig.OutlierDetectWhen
    ON_RECOVER: RecoverConfig.OutlierDetectWhen
    ALWAYS: RecoverConfig.OutlierDetectWhen
    SLEEPWINDOW_FIELD_NUMBER: _ClassVar[int]
    MAXRETRYAFTERHALFOPEN_FIELD_NUMBER: _ClassVar[int]
    REQUESTRATEAFTERHALFOPEN_FIELD_NUMBER: _ClassVar[int]
    SUCCESSRATETOCLOSE_FIELD_NUMBER: _ClassVar[int]
    REQUESTCOUNTAFTERHALFOPEN_FIELD_NUMBER: _ClassVar[int]
    OUTLIERDETECTWHEN_FIELD_NUMBER: _ClassVar[int]
    sleepWindow: _duration_pb2.Duration
    maxRetryAfterHalfOpen: _wrappers_pb2.UInt32Value
    requestRateAfterHalfOpen: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.UInt32Value]
    successRateToClose: _wrappers_pb2.UInt32Value
    requestCountAfterHalfOpen: _wrappers_pb2.UInt32Value
    outlierDetectWhen: RecoverConfig.OutlierDetectWhen
    def __init__(self, sleepWindow: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., maxRetryAfterHalfOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., requestRateAfterHalfOpen: _Optional[_Iterable[_Union[_wrappers_pb2.UInt32Value, _Mapping]]] = ..., successRateToClose: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., requestCountAfterHalfOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., outlierDetectWhen: _Optional[_Union[RecoverConfig.OutlierDetectWhen, str]] = ...) -> None: ...

class CbPolicy(_message.Message):
    __slots__ = ["errorRate", "slowRate", "judgeDuration", "maxEjectionPercent", "consecutive"]
    class ErrRateConfig(_message.Message):
        __slots__ = ["enable", "requestVolumeThreshold", "errorRateToPreserved", "errorRateToOpen", "specials"]
        class SpecialConfig(_message.Message):
            __slots__ = ["type", "errorCodes", "errorRateToPreserved", "errorRateToOpen"]
            TYPE_FIELD_NUMBER: _ClassVar[int]
            ERRORCODES_FIELD_NUMBER: _ClassVar[int]
            ERRORRATETOPRESERVED_FIELD_NUMBER: _ClassVar[int]
            ERRORRATETOOPEN_FIELD_NUMBER: _ClassVar[int]
            type: _wrappers_pb2.StringValue
            errorCodes: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.Int64Value]
            errorRateToPreserved: _wrappers_pb2.UInt32Value
            errorRateToOpen: _wrappers_pb2.UInt32Value
            def __init__(self, type: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., errorCodes: _Optional[_Iterable[_Union[_wrappers_pb2.Int64Value, _Mapping]]] = ..., errorRateToPreserved: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., errorRateToOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...
        ENABLE_FIELD_NUMBER: _ClassVar[int]
        REQUESTVOLUMETHRESHOLD_FIELD_NUMBER: _ClassVar[int]
        ERRORRATETOPRESERVED_FIELD_NUMBER: _ClassVar[int]
        ERRORRATETOOPEN_FIELD_NUMBER: _ClassVar[int]
        SPECIALS_FIELD_NUMBER: _ClassVar[int]
        enable: _wrappers_pb2.BoolValue
        requestVolumeThreshold: _wrappers_pb2.UInt32Value
        errorRateToPreserved: _wrappers_pb2.UInt32Value
        errorRateToOpen: _wrappers_pb2.UInt32Value
        specials: _containers.RepeatedCompositeFieldContainer[CbPolicy.ErrRateConfig.SpecialConfig]
        def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., requestVolumeThreshold: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., errorRateToPreserved: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., errorRateToOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., specials: _Optional[_Iterable[_Union[CbPolicy.ErrRateConfig.SpecialConfig, _Mapping]]] = ...) -> None: ...
    class SlowRateConfig(_message.Message):
        __slots__ = ["enable", "maxRt", "slowRateToPreserved", "slowRateToOpen"]
        ENABLE_FIELD_NUMBER: _ClassVar[int]
        MAXRT_FIELD_NUMBER: _ClassVar[int]
        SLOWRATETOPRESERVED_FIELD_NUMBER: _ClassVar[int]
        SLOWRATETOOPEN_FIELD_NUMBER: _ClassVar[int]
        enable: _wrappers_pb2.BoolValue
        maxRt: _duration_pb2.Duration
        slowRateToPreserved: _wrappers_pb2.UInt32Value
        slowRateToOpen: _wrappers_pb2.UInt32Value
        def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., maxRt: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., slowRateToPreserved: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., slowRateToOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...
    class ConsecutiveErrConfig(_message.Message):
        __slots__ = ["enable", "consecutiveErrorToPreserved", "consecutiveErrorToOpen"]
        ENABLE_FIELD_NUMBER: _ClassVar[int]
        CONSECUTIVEERRORTOPRESERVED_FIELD_NUMBER: _ClassVar[int]
        CONSECUTIVEERRORTOOPEN_FIELD_NUMBER: _ClassVar[int]
        enable: _wrappers_pb2.BoolValue
        consecutiveErrorToPreserved: _wrappers_pb2.UInt32Value
        consecutiveErrorToOpen: _wrappers_pb2.UInt32Value
        def __init__(self, enable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., consecutiveErrorToPreserved: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., consecutiveErrorToOpen: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...
    ERRORRATE_FIELD_NUMBER: _ClassVar[int]
    SLOWRATE_FIELD_NUMBER: _ClassVar[int]
    JUDGEDURATION_FIELD_NUMBER: _ClassVar[int]
    MAXEJECTIONPERCENT_FIELD_NUMBER: _ClassVar[int]
    CONSECUTIVE_FIELD_NUMBER: _ClassVar[int]
    errorRate: CbPolicy.ErrRateConfig
    slowRate: CbPolicy.SlowRateConfig
    judgeDuration: _duration_pb2.Duration
    maxEjectionPercent: _wrappers_pb2.UInt32Value
    consecutive: CbPolicy.ConsecutiveErrConfig
    def __init__(self, errorRate: _Optional[_Union[CbPolicy.ErrRateConfig, _Mapping]] = ..., slowRate: _Optional[_Union[CbPolicy.SlowRateConfig, _Mapping]] = ..., judgeDuration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., maxEjectionPercent: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., consecutive: _Optional[_Union[CbPolicy.ConsecutiveErrConfig, _Mapping]] = ...) -> None: ...

class DestinationSet(_message.Message):
    __slots__ = ["service", "namespace", "metadata", "resource", "type", "scope", "metricWindow", "metricPrecision", "updateInterval", "recover", "policy", "method", "errorCodes"]
    class Resource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        SUBSET: _ClassVar[DestinationSet.Resource]
        INSTANCE: _ClassVar[DestinationSet.Resource]
    SUBSET: DestinationSet.Resource
    INSTANCE: DestinationSet.Resource
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        GLOBAL: _ClassVar[DestinationSet.Type]
        LOCAL: _ClassVar[DestinationSet.Type]
    GLOBAL: DestinationSet.Type
    LOCAL: DestinationSet.Type
    class Scope(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        ALL: _ClassVar[DestinationSet.Scope]
        CURRENT: _ClassVar[DestinationSet.Scope]
    ALL: DestinationSet.Scope
    CURRENT: DestinationSet.Scope
    class MetadataEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    METRICWINDOW_FIELD_NUMBER: _ClassVar[int]
    METRICPRECISION_FIELD_NUMBER: _ClassVar[int]
    UPDATEINTERVAL_FIELD_NUMBER: _ClassVar[int]
    RECOVER_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    ERRORCODES_FIELD_NUMBER: _ClassVar[int]
    service: _wrappers_pb2.StringValue
    namespace: _wrappers_pb2.StringValue
    metadata: _containers.MessageMap[str, _model_pb2.MatchString]
    resource: DestinationSet.Resource
    type: DestinationSet.Type
    scope: DestinationSet.Scope
    metricWindow: _duration_pb2.Duration
    metricPrecision: _wrappers_pb2.UInt32Value
    updateInterval: _duration_pb2.Duration
    recover: RecoverConfig
    policy: CbPolicy
    method: _model_pb2.MatchString
    errorCodes: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.Int64Value]
    def __init__(self, service: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., namespace: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., metadata: _Optional[_Mapping[str, _model_pb2.MatchString]] = ..., resource: _Optional[_Union[DestinationSet.Resource, str]] = ..., type: _Optional[_Union[DestinationSet.Type, str]] = ..., scope: _Optional[_Union[DestinationSet.Scope, str]] = ..., metricWindow: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., metricPrecision: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., updateInterval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., recover: _Optional[_Union[RecoverConfig, _Mapping]] = ..., policy: _Optional[_Union[CbPolicy, _Mapping]] = ..., method: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ..., errorCodes: _Optional[_Iterable[_Union[_wrappers_pb2.Int64Value, _Mapping]]] = ...) -> None: ...

class CbRule(_message.Message):
    __slots__ = ["sources", "destinations"]
    SOURCES_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    sources: _containers.RepeatedCompositeFieldContainer[SourceMatcher]
    destinations: _containers.RepeatedCompositeFieldContainer[DestinationSet]
    def __init__(self, sources: _Optional[_Iterable[_Union[SourceMatcher, _Mapping]]] = ..., destinations: _Optional[_Iterable[_Union[DestinationSet, _Mapping]]] = ...) -> None: ...

class RuleMatcher(_message.Message):
    __slots__ = ["source", "destination"]
    class SourceService(_message.Message):
        __slots__ = ["service", "namespace"]
        SERVICE_FIELD_NUMBER: _ClassVar[int]
        NAMESPACE_FIELD_NUMBER: _ClassVar[int]
        service: str
        namespace: str
        def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ...) -> None: ...
    class DestinationService(_message.Message):
        __slots__ = ["service", "namespace", "method"]
        SERVICE_FIELD_NUMBER: _ClassVar[int]
        NAMESPACE_FIELD_NUMBER: _ClassVar[int]
        METHOD_FIELD_NUMBER: _ClassVar[int]
        service: str
        namespace: str
        method: _model_pb2.MatchString
        def __init__(self, service: _Optional[str] = ..., namespace: _Optional[str] = ..., method: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_FIELD_NUMBER: _ClassVar[int]
    source: RuleMatcher.SourceService
    destination: RuleMatcher.DestinationService
    def __init__(self, source: _Optional[_Union[RuleMatcher.SourceService, _Mapping]] = ..., destination: _Optional[_Union[RuleMatcher.DestinationService, _Mapping]] = ...) -> None: ...

class CircuitBreakerRule(_message.Message):
    __slots__ = ["id", "name", "namespace", "enable", "revision", "ctime", "mtime", "etime", "description", "level", "rule_matcher", "error_conditions", "trigger_condition", "max_ejection_percent", "recoverCondition", "faultDetectConfig", "fallbackConfig"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    ETIME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    RULE_MATCHER_FIELD_NUMBER: _ClassVar[int]
    ERROR_CONDITIONS_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_CONDITION_FIELD_NUMBER: _ClassVar[int]
    MAX_EJECTION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    RECOVERCONDITION_FIELD_NUMBER: _ClassVar[int]
    FAULTDETECTCONFIG_FIELD_NUMBER: _ClassVar[int]
    FALLBACKCONFIG_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    namespace: str
    enable: bool
    revision: str
    ctime: str
    mtime: str
    etime: str
    description: str
    level: Level
    rule_matcher: RuleMatcher
    error_conditions: _containers.RepeatedCompositeFieldContainer[ErrorCondition]
    trigger_condition: _containers.RepeatedCompositeFieldContainer[TriggerCondition]
    max_ejection_percent: int
    recoverCondition: RecoverCondition
    faultDetectConfig: FaultDetectConfig
    fallbackConfig: FallbackConfig
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., namespace: _Optional[str] = ..., enable: bool = ..., revision: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., etime: _Optional[str] = ..., description: _Optional[str] = ..., level: _Optional[_Union[Level, str]] = ..., rule_matcher: _Optional[_Union[RuleMatcher, _Mapping]] = ..., error_conditions: _Optional[_Iterable[_Union[ErrorCondition, _Mapping]]] = ..., trigger_condition: _Optional[_Iterable[_Union[TriggerCondition, _Mapping]]] = ..., max_ejection_percent: _Optional[int] = ..., recoverCondition: _Optional[_Union[RecoverCondition, _Mapping]] = ..., faultDetectConfig: _Optional[_Union[FaultDetectConfig, _Mapping]] = ..., fallbackConfig: _Optional[_Union[FallbackConfig, _Mapping]] = ...) -> None: ...

class ErrorCondition(_message.Message):
    __slots__ = ["input_type", "condition"]
    class InputType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[ErrorCondition.InputType]
        RET_CODE: _ClassVar[ErrorCondition.InputType]
        DELAY: _ClassVar[ErrorCondition.InputType]
    UNKNOWN: ErrorCondition.InputType
    RET_CODE: ErrorCondition.InputType
    DELAY: ErrorCondition.InputType
    INPUT_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    input_type: ErrorCondition.InputType
    condition: _model_pb2.MatchString
    def __init__(self, input_type: _Optional[_Union[ErrorCondition.InputType, str]] = ..., condition: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...

class TriggerCondition(_message.Message):
    __slots__ = ["trigger_type", "error_count", "error_percent", "interval", "minimum_request"]
    class TriggerType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[TriggerCondition.TriggerType]
        ERROR_RATE: _ClassVar[TriggerCondition.TriggerType]
        CONSECUTIVE_ERROR: _ClassVar[TriggerCondition.TriggerType]
    UNKNOWN: TriggerCondition.TriggerType
    ERROR_RATE: TriggerCondition.TriggerType
    CONSECUTIVE_ERROR: TriggerCondition.TriggerType
    TRIGGER_TYPE_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    ERROR_PERCENT_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_REQUEST_FIELD_NUMBER: _ClassVar[int]
    trigger_type: TriggerCondition.TriggerType
    error_count: int
    error_percent: int
    interval: int
    minimum_request: int
    def __init__(self, trigger_type: _Optional[_Union[TriggerCondition.TriggerType, str]] = ..., error_count: _Optional[int] = ..., error_percent: _Optional[int] = ..., interval: _Optional[int] = ..., minimum_request: _Optional[int] = ...) -> None: ...

class RecoverCondition(_message.Message):
    __slots__ = ["sleep_window", "consecutiveSuccess"]
    SLEEP_WINDOW_FIELD_NUMBER: _ClassVar[int]
    CONSECUTIVESUCCESS_FIELD_NUMBER: _ClassVar[int]
    sleep_window: int
    consecutiveSuccess: int
    def __init__(self, sleep_window: _Optional[int] = ..., consecutiveSuccess: _Optional[int] = ...) -> None: ...

class FaultDetectConfig(_message.Message):
    __slots__ = ["enable"]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    enable: bool
    def __init__(self, enable: bool = ...) -> None: ...

class FallbackConfig(_message.Message):
    __slots__ = ["enable", "response"]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    enable: bool
    response: FallbackResponse
    def __init__(self, enable: bool = ..., response: _Optional[_Union[FallbackResponse, _Mapping]] = ...) -> None: ...

class FallbackResponse(_message.Message):
    __slots__ = ["code", "headers", "body"]
    class MessageHeader(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CODE_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    code: int
    headers: _containers.RepeatedCompositeFieldContainer[FallbackResponse.MessageHeader]
    body: str
    def __init__(self, code: _Optional[int] = ..., headers: _Optional[_Iterable[_Union[FallbackResponse.MessageHeader, _Mapping]]] = ..., body: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..config_manage import config_file_pb2 as config__file__pb2
from ..config_manage import config_file_response_pb2 as config__file__response__pb2


class PolarisConfigGRPCStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConfigFile = channel.unary_unary(
                '/v1.PolarisConfigGRPC/GetConfigFile',
                request_serializer=config__file__pb2.ClientConfigFileInfo.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientResponse.FromString,
                )
        self.CreateConfigFile = channel.unary_unary(
                '/v1.PolarisConfigGRPC/CreateConfigFile',
                request_serializer=config__file__pb2.ConfigFile.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientResponse.FromString,
                )
        self.UpdateConfigFile = channel.unary_unary(
                '/v1.PolarisConfigGRPC/UpdateConfigFile',
                request_serializer=config__file__pb2.ConfigFile.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientResponse.FromString,
                )
        self.PublishConfigFile = channel.unary_unary(
                '/v1.PolarisConfigGRPC/PublishConfigFile',
                request_serializer=config__file__pb2.ConfigFileRelease.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientResponse.FromString,
                )
        self.WatchConfigFiles = channel.unary_unary(
                '/v1.PolarisConfigGRPC/WatchConfigFiles',
                request_serializer=config__file__pb2.ClientWatchConfigFileRequest.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientResponse.FromString,
                )
        self.GetConfigFileMetadataList = channel.unary_unary(
                '/v1.PolarisConfigGRPC/GetConfigFileMetadataList',
                request_serializer=config__file__pb2.ConfigFileGroupRequest.SerializeToString,
                response_deserializer=config__file__response__pb2.ConfigClientListResponse.FromString,
                )
        self.Discover = channel.stream_stream(
                '/v1.PolarisConfigGRPC/Discover',
                request_serializer=config__file__pb2.ConfigDiscoverRequest.SerializeToString,
                response_deserializer=config__file__pb2.ConfigDiscoverResponse.FromString,
                )


class PolarisConfigGRPCServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConfigFile(self, request, context):
        """拉取配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConfigFile(self, request, context):
        """创建配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConfigFile(self, request, context):
        """更新配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishConfigFile(self, request, context):
        """发布配置
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchConfigFiles(self, request, context):
        """订阅配置变更
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigFileMetadataList(self, request, context):
        """拉取指定配置分组下的配置文件列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Discover(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolarisConfigGRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigFile,
                    request_deserializer=config__file__pb2.ClientConfigFileInfo.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientResponse.SerializeToString,
            ),
            'CreateConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConfigFile,
                    request_deserializer=config__file__pb2.ConfigFile.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientResponse.SerializeToString,
            ),
            'UpdateConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConfigFile,
                    request_deserializer=config__file__pb2.ConfigFile.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientResponse.SerializeToString,
            ),
            'PublishConfigFile': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishConfigFile,
                    request_deserializer=config__file__pb2.ConfigFileRelease.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientResponse.SerializeToString,
            ),
            'WatchConfigFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.WatchConfigFiles,
                    request_deserializer=config__file__pb2.ClientWatchConfigFileRequest.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientResponse.SerializeToString,
            ),
            'GetConfigFileMetadataList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigFileMetadataList,
                    request_deserializer=config__file__pb2.ConfigFileGroupRequest.FromString,
                    response_serializer=config__file__response__pb2.ConfigClientListResponse.SerializeToString,
            ),
            'Discover': grpc.stream_stream_rpc_method_handler(
                    servicer.Discover,
                    request_deserializer=config__file__pb2.ConfigDiscoverRequest.FromString,
                    response_serializer=config__file__pb2.ConfigDiscoverResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.PolarisConfigGRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PolarisConfigGRPC(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/GetConfigFile',
            config__file__pb2.ClientConfigFileInfo.SerializeToString,
            config__file__response__pb2.ConfigClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/CreateConfigFile',
            config__file__pb2.ConfigFile.SerializeToString,
            config__file__response__pb2.ConfigClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/UpdateConfigFile',
            config__file__pb2.ConfigFile.SerializeToString,
            config__file__response__pb2.ConfigClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishConfigFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/PublishConfigFile',
            config__file__pb2.ConfigFileRelease.SerializeToString,
            config__file__response__pb2.ConfigClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchConfigFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/WatchConfigFiles',
            config__file__pb2.ClientWatchConfigFileRequest.SerializeToString,
            config__file__response__pb2.ConfigClientResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConfigFileMetadataList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.PolarisConfigGRPC/GetConfigFileMetadataList',
            config__file__pb2.ConfigFileGroupRequest.SerializeToString,
            config__file__response__pb2.ConfigClientListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Discover(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/v1.PolarisConfigGRPC/Discover',
            config__file__pb2.ConfigDiscoverRequest.SerializeToString,
            config__file__pb2.ConfigDiscoverResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Namespace(_message.Message):
    __slots__ = ["name", "comment", "owners", "token", "ctime", "mtime", "total_service_count", "total_health_instance_count", "total_instance_count", "user_ids", "group_ids", "remove_user_ids", "remove_group_ids", "id", "editable", "service_export_to"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SERVICE_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_HEALTH_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_INSTANCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_USER_IDS_FIELD_NUMBER: _ClassVar[int]
    REMOVE_GROUP_IDS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_EXPORT_TO_FIELD_NUMBER: _ClassVar[int]
    name: _wrappers_pb2.StringValue
    comment: _wrappers_pb2.StringValue
    owners: _wrappers_pb2.StringValue
    token: _wrappers_pb2.StringValue
    ctime: _wrappers_pb2.StringValue
    mtime: _wrappers_pb2.StringValue
    total_service_count: _wrappers_pb2.UInt32Value
    total_health_instance_count: _wrappers_pb2.UInt32Value
    total_instance_count: _wrappers_pb2.UInt32Value
    user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_user_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    remove_group_ids: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    id: _wrappers_pb2.StringValue
    editable: _wrappers_pb2.BoolValue
    service_export_to: _containers.RepeatedCompositeFieldContainer[_wrappers_pb2.StringValue]
    def __init__(self, name: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., comment: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., owners: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., token: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., ctime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., mtime: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., total_service_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., total_health_instance_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., total_instance_count: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ..., user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_user_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., remove_group_ids: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ..., id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., editable: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ..., service_export_to: _Optional[_Iterable[_Union[_wrappers_pb2.StringValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import service_pb2 as service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rrequest.proto\x12\x02v1\x1a\rservice.proto\"-\n\x0e\x44iscoverFilter\x12\x1b\n\x13OnlyHealthyInstance\x18\x01 \x01(\x08\"\xd0\x02\n\x0f\x44iscoverRequest\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.v1.DiscoverRequest.DiscoverRequestType\x12\x1c\n\x07service\x18\x02 \x01(\x0b\x32\x0b.v1.Service\x12\"\n\x06\x46ilter\x18\x1e \x01(\x0b\x32\x12.v1.DiscoverFilter\"\xbd\x01\n\x13\x44iscoverRequestType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\x12\x0b\n\x07\x43LUSTER\x10\x02\x12\x0b\n\x07ROUTING\x10\x03\x12\x0e\n\nRATE_LIMIT\x10\x04\x12\x13\n\x0f\x43IRCUIT_BREAKER\x10\x05\x12\x0c\n\x08SERVICES\x10\x06\x12\x0e\n\nNAMESPACES\x10\x0c\x12\x12\n\x0e\x46\x41ULT_DETECTOR\x10\r\x12\x14\n\x10SERVICE_CONTRACT\x10\x0e\"\x04\x08\x07\x10\x0bJ\x04\x08\x03\x10\x05\x42\x8d\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0cRequestProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\014RequestProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_DISCOVERFILTER']._serialized_start=36
  _globals['_DISCOVERFILTER']._serialized_end=81
  _globals['_DISCOVERREQUEST']._serialized_start=84
  _globals['_DISCOVERREQUEST']._serialized_end=420
  _globals['_DISCOVERREQUEST_DISCOVERREQUESTTYPE']._serialized_start=225
  _globals['_DISCOVERREQUEST_DISCOVERREQUESTTYPE']._serialized_end=414
# @@protoc_insertion_point(module_scope)



from .config_file_pb2_grpc import *
from .config_file_response_pb2_grpc import *
from .grpc_config_api_pb2_grpc import *
from .grpc_config_api_pb2 import *
from .config_file_pb2 import *
from .config_file_response_pb2 import *


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpcapi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import client_pb2 as client__pb2
from ..service_manage import service_pb2 as service__pb2
from ..service_manage import request_pb2 as request__pb2
from ..service_manage import response_pb2 as response__pb2
from ..service_manage import heartbeat_pb2 as heartbeat__pb2
from ..service_manage import contract_pb2 as contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgrpcapi.proto\x12\x02v1\x1a\x0c\x63lient.proto\x1a\rservice.proto\x1a\rrequest.proto\x1a\x0eresponse.proto\x1a\x0fheartbeat.proto\x1a\x0e\x63ontract.proto2\x87\x02\n\x0bPolarisGRPC\x12*\n\x0cReportClient\x12\n.v1.Client\x1a\x0c.v1.Response\"\x00\x12\x30\n\x10RegisterInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12\x32\n\x12\x44\x65registerInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12;\n\x08\x44iscover\x12\x13.v1.DiscoverRequest\x1a\x14.v1.DiscoverResponse\"\x00(\x01\x30\x01\x12)\n\tHeartbeat\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x32\xf5\x01\n\x14PolarisHeartbeatGRPC\x12\x45\n\x0e\x42\x61tchHeartbeat\x12\x15.v1.HeartbeatsRequest\x1a\x16.v1.HeartbeatsResponse\"\x00(\x01\x30\x01\x12J\n\x11\x42\x61tchGetHeartbeat\x12\x18.v1.GetHeartbeatsRequest\x1a\x19.v1.GetHeartbeatsResponse\"\x00\x12J\n\x11\x42\x61tchDelHeartbeat\x12\x18.v1.DelHeartbeatsRequest\x1a\x19.v1.DelHeartbeatsResponse\"\x00\x32Z\n\x1aPolarisServiceContractGRPC\x12<\n\x15ReportServiceContract\x12\x13.v1.ServiceContract\x1a\x0c.v1.Response\"\x00\x42\x93\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x12PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpcapi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\022PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_POLARISGRPC']._serialized_start=115
  _globals['_POLARISGRPC']._serialized_end=378
  _globals['_POLARISHEARTBEATGRPC']._serialized_start=381
  _globals['_POLARISHEARTBEATGRPC']._serialized_end=626
  _globals['_POLARISSERVICECONTRACTGRPC']._serialized_start=628
  _globals['_POLARISSERVICECONTRACTGRPC']._serialized_end=718
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63onfig_file.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\xeb\x07\n\x0f\x43onfigFileGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfileCount\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x38\n\x08user_ids\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\r \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12,\n\x08\x65\x64itable\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x05owner\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62usiness\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ndepartment\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x08metadata\x18\x13 \x03(\x0b\x32!.v1.ConfigFileGroup.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x06\n\nConfigFile\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\t \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0crelease_time\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nrelease_by\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\tencrypted\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0c\x65ncrypt_algo\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"g\n\rConfigFileTag\x12)\n\x03key\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x80\x07\n\x11\x43onfigFileRelease\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x0e \x03(\x0b\x32\x11.v1.ConfigFileTag\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x06\x66ormat\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13release_description\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04type\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12$\n\x0b\x62\x65ta_labels\x18\x13 \x03(\x0b\x32\x0f.v1.ClientLabel\"\xe2\x06\n\x18\x43onfigFileReleaseHistory\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04type\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x0c \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06reason\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13release_description\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xbe\x03\n\x12\x43onfigFileTemplate\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x9e\x04\n\x14\x43lientConfigFileInfo\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12)\n\x03md5\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x07 \x03(\x0b\x32\x11.v1.ConfigFileTag\x12-\n\tencrypted\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\npublic_key\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0crelease_time\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0crelease_time\"\xb2\x01\n\x1c\x43lientWatchConfigFileRequest\x12/\n\tclient_ip\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cservice_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x0bwatch_files\x18\x03 \x03(\x0b\x32\x18.v1.ClientConfigFileInfo\"\xa5\x01\n\x17\x43onfigFileExportRequest\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06groups\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05names\x18\x03 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"\xe8\x04\n\x15\x43onfigFilePublishInfo\x12@\n\x0crelease_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0crelease_name\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tfile_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tfile_name\x12-\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x13release_description\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x13release_description\x12:\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcreate_by\x12:\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tmodify_by\x12\x1f\n\x04tags\x18\x0e \x03(\x0b\x32\x11.v1.ConfigFileTag\"\x94\x02\n\x16\x43onfigFileGroupRequest\x12.\n\x08revision\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x41\n\x11\x63onfig_file_group\x18\x02 \x01(\x0b\x32\x13.v1.ConfigFileGroupR\x11\x63onfig_file_group\x12R\n\rclient_labels\x18\x0c \x03(\x0b\x32,.v1.ConfigFileGroupRequest.ClientLabelsEntryR\rclient_labels\x1a\x33\n\x11\x43lientLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x15\x43onfigDiscoverRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.v1.ConfigDiscoverType\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x10\n\x08revision\x18\x04 \x01(\t\"\xb5\x02\n\x16\x43onfigDiscoverResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04info\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12$\n\x04type\x18\x04 \x01(\x0e\x32\x16.v1.ConfigDiscoverType\x12:\n\x0b\x63onfig_file\x18\x05 \x01(\x0b\x32\x18.v1.ClientConfigFileInfoR\x0b\x63onfig_file\x12\x46\n\x11\x63onfig_file_names\x18\x06 \x03(\x0b\x32\x18.v1.ClientConfigFileInfoR\x11\x63onfig_file_names\x12\x43\n\x12\x63onfig_file_groups\x18\x07 \x03(\x0b\x32\x13.v1.ConfigFileGroupR\x12\x63onfig_file_groups*[\n\x12\x43onfigDiscoverType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0b\x43ONFIG_FILE\x10\x01\x12\x14\n\x10\x43ONFIG_FILE_LIST\x10\x02\x12\x11\n\rCONFIG_GROUPS\x10\x03\x42\x8e\x01\n6com.tencent.polaris.specification.api.v1.config.manageB\x0f\x43onfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'config_file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.tencent.polaris.specification.api.v1.config.manageB\017ConfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manage'
  _CONFIGFILEGROUP_METADATAENTRY._options = None
  _CONFIGFILEGROUP_METADATAENTRY._serialized_options = b'8\001'
  _CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY._options = None
  _CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY._serialized_options = b'8\001'
  _globals['_CONFIGDISCOVERTYPE']._serialized_start=6432
  _globals['_CONFIGDISCOVERTYPE']._serialized_end=6523
  _globals['_CONFIGFILEGROUP']._serialized_start=71
  _globals['_CONFIGFILEGROUP']._serialized_end=1074
  _globals['_CONFIGFILEGROUP_METADATAENTRY']._serialized_start=1027
  _globals['_CONFIGFILEGROUP_METADATAENTRY']._serialized_end=1074
  _globals['_CONFIGFILE']._serialized_start=1077
  _globals['_CONFIGFILE']._serialized_end=1889
  _globals['_CONFIGFILETAG']._serialized_start=1891
  _globals['_CONFIGFILETAG']._serialized_end=1994
  _globals['_CONFIGFILERELEASE']._serialized_start=1997
  _globals['_CONFIGFILERELEASE']._serialized_end=2893
  _globals['_CONFIGFILERELEASEHISTORY']._serialized_start=2896
  _globals['_CONFIGFILERELEASEHISTORY']._serialized_end=3762
  _globals['_CONFIGFILETEMPLATE']._serialized_start=3765
  _globals['_CONFIGFILETEMPLATE']._serialized_end=4211
  _globals['_CLIENTCONFIGFILEINFO']._serialized_start=4214
  _globals['_CLIENTCONFIGFILEINFO']._serialized_end=4756
  _globals['_CLIENTWATCHCONFIGFILEREQUEST']._serialized_start=4759
  _globals['_CLIENTWATCHCONFIGFILEREQUEST']._serialized_end=4937
  _globals['_CONFIGFILEEXPORTREQUEST']._serialized_start=4940
  _globals['_CONFIGFILEEXPORTREQUEST']._serialized_end=5105
  _globals['_CONFIGFILEPUBLISHINFO']._serialized_start=5108
  _globals['_CONFIGFILEPUBLISHINFO']._serialized_end=5724
  _globals['_CONFIGFILEGROUPREQUEST']._serialized_start=5727
  _globals['_CONFIGFILEGROUPREQUEST']._serialized_end=6003
  _globals['_CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY']._serialized_start=5952
  _globals['_CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY']._serialized_end=6003
  _globals['_CONFIGDISCOVERREQUEST']._serialized_start=6005
  _globals['_CONFIGDISCOVERREQUEST']._serialized_end=6118
  _globals['_CONFIGDISCOVERRESPONSE']._serialized_start=6121
  _globals['_CONFIGDISCOVERRESPONSE']._serialized_end=6430
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: circuitbreaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ircuitbreaker.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x0bmodel.proto\"\x8e\x06\n\x0e\x43ircuitBreaker\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07service\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11service_namespace\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1c\n\x08inbounds\x18\x07 \x03(\x0b\x32\n.v1.CbRule\x12\x1d\n\toutbounds\x18\x08 \x03(\x0b\x32\n.v1.CbRule\x12+\n\x05token\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06owners\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62usiness\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ndepartment\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12%\n\x05rules\x18\x15 \x03(\x0b\x32\x16.v1.CircuitBreakerRuleJ\x04\x08\x11\x10\x15\"\xde\x01\n\rSourceMatcher\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x06labels\x18\x03 \x03(\x0b\x32\x1d.v1.SourceMatcher.LabelsEntry\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xb3\x03\n\rRecoverConfig\x12.\n\x0bsleepWindow\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x15maxRetryAfterHalfOpen\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x18requestRateAfterHalfOpen\x18\x03 \x03(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12successRateToClose\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19requestCountAfterHalfOpen\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11outlierDetectWhen\x18\x06 \x01(\x0e\x32#.v1.RecoverConfig.OutlierDetectWhen\":\n\x11OutlierDetectWhen\x12\t\n\x05NEVER\x10\x00\x12\x0e\n\nON_RECOVER\x10\x01\x12\n\n\x06\x41LWAYS\x10\x02\"\xb9\t\n\x08\x43\x62Policy\x12-\n\terrorRate\x18\x01 \x01(\x0b\x32\x1a.v1.CbPolicy.ErrRateConfig\x12-\n\x08slowRate\x18\x02 \x01(\x0b\x32\x1b.v1.CbPolicy.SlowRateConfig\x12\x30\n\rjudgeDuration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x12maxEjectionPercent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x36\n\x0b\x63onsecutive\x18\x05 \x01(\x0b\x32!.v1.CbPolicy.ConsecutiveErrConfig\x1a\x8a\x04\n\rErrRateConfig\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16requestVolumeThreshold\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14\x65rrorRateToPreserved\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0f\x65rrorRateToOpen\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x08specials\x18\x05 \x03(\x0b\x32(.v1.CbPolicy.ErrRateConfig.SpecialConfig\x1a\xdf\x01\n\rSpecialConfig\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\nerrorCodes\x18\x02 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x14\x65rrorRateToPreserved\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0f\x65rrorRateToOpen\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1a\xd7\x01\n\x0eSlowRateConfig\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x05maxRt\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x13slowRateToPreserved\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0eslowRateToOpen\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1a\xc3\x01\n\x14\x43onsecutiveErrConfig\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1b\x63onsecutiveErrorToPreserved\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12<\n\x16\x63onsecutiveErrorToOpen\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xf8\x05\n\x0e\x44\x65stinationSet\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x08metadata\x18\x03 \x03(\x0b\x32 .v1.DestinationSet.MetadataEntry\x12-\n\x08resource\x18\x04 \x01(\x0e\x32\x1b.v1.DestinationSet.Resource\x12%\n\x04type\x18\x05 \x01(\x0e\x32\x17.v1.DestinationSet.Type\x12\'\n\x05scope\x18\x06 \x01(\x0e\x32\x18.v1.DestinationSet.Scope\x12/\n\x0cmetricWindow\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x0fmetricPrecision\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0eupdateInterval\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\"\n\x07recover\x18\n \x01(\x0b\x32\x11.v1.RecoverConfig\x12\x1c\n\x06policy\x18\x0b \x01(\x0b\x32\x0c.v1.CbPolicy\x12\x1f\n\x06method\x18\x0c \x01(\x0b\x32\x0f.v1.MatchString\x12/\n\nerrorCodes\x18\r \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x1a@\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"$\n\x08Resource\x12\n\n\x06SUBSET\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\"\x1d\n\x04Type\x12\n\n\x06GLOBAL\x10\x00\x12\t\n\x05LOCAL\x10\x01\"\x1d\n\x05Scope\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43URRENT\x10\x01\"V\n\x06\x43\x62Rule\x12\"\n\x07sources\x18\x01 \x03(\x0b\x32\x11.v1.SourceMatcher\x12(\n\x0c\x64\x65stinations\x18\x02 \x03(\x0b\x32\x12.v1.DestinationSet\"\x85\x02\n\x0bRuleMatcher\x12-\n\x06source\x18\x01 \x01(\x0b\x32\x1d.v1.RuleMatcher.SourceService\x12\x37\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\".v1.RuleMatcher.DestinationService\x1a\x33\n\rSourceService\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x1aY\n\x12\x44\x65stinationService\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x1f\n\x06method\x18\x03 \x01(\x0b\x32\x0f.v1.MatchString\"\xf7\x03\n\x12\x43ircuitBreakerRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\x10\n\x08revision\x18\x05 \x01(\t\x12\r\n\x05\x63time\x18\x06 \x01(\t\x12\r\n\x05mtime\x18\x07 \x01(\t\x12\r\n\x05\x65time\x18\x08 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x18\n\x05level\x18\x15 \x01(\x0e\x32\t.v1.Level\x12%\n\x0crule_matcher\x18\x16 \x01(\x0b\x32\x0f.v1.RuleMatcher\x12,\n\x10\x65rror_conditions\x18\x17 \x03(\x0b\x32\x12.v1.ErrorCondition\x12/\n\x11trigger_condition\x18\x18 \x03(\x0b\x32\x14.v1.TriggerCondition\x12\x1c\n\x14max_ejection_percent\x18\x19 \x01(\r\x12.\n\x10recoverCondition\x18\x1a \x01(\x0b\x32\x14.v1.RecoverCondition\x12\x30\n\x11\x66\x61ultDetectConfig\x18\x1b \x01(\x0b\x32\x15.v1.FaultDetectConfig\x12*\n\x0e\x66\x61llbackConfig\x18\x1c \x01(\x0b\x32\x12.v1.FallbackConfigJ\x04\x08\n\x10\x15\"\x99\x01\n\x0e\x45rrorCondition\x12\x30\n\ninput_type\x18\x01 \x01(\x0e\x32\x1c.v1.ErrorCondition.InputType\x12\"\n\tcondition\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString\"1\n\tInputType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08RET_CODE\x10\x01\x12\t\n\x05\x44\x45LAY\x10\x02\"\xe4\x01\n\x10TriggerCondition\x12\x36\n\x0ctrigger_type\x18\x01 \x01(\x0e\x32 .v1.TriggerCondition.TriggerType\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\r\x12\x15\n\rerror_percent\x18\x03 \x01(\r\x12\x10\n\x08interval\x18\x04 \x01(\r\x12\x17\n\x0fminimum_request\x18\x05 \x01(\r\"A\n\x0bTriggerType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nERROR_RATE\x10\x01\x12\x15\n\x11\x43ONSECUTIVE_ERROR\x10\x02\"D\n\x10RecoverCondition\x12\x14\n\x0csleep_window\x18\x01 \x01(\r\x12\x1a\n\x12\x63onsecutiveSuccess\x18\x02 \x01(\r\"#\n\x11\x46\x61ultDetectConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"H\n\x0e\x46\x61llbackConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12&\n\x08response\x18\x02 \x01(\x0b\x32\x14.v1.FallbackResponse\"\x90\x01\n\x10\x46\x61llbackResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x33\n\x07headers\x18\x02 \x03(\x0b\x32\".v1.FallbackResponse.MessageHeader\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a+\n\rMessageHeader\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*F\n\x05Level\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\n\n\x06METHOD\x10\x02\x12\t\n\x05GROUP\x10\x03\x12\x0c\n\x08INSTANCE\x10\x04\x42\x96\x01\n8com.tencent.polaris.specification.api.v1.fault.toleranceB\x13\x43ircuitBreakerProtoZEgithub.com/polarismesh/specification/source/go/api/v1/fault_toleranceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'circuitbreaker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8com.tencent.polaris.specification.api.v1.fault.toleranceB\023CircuitBreakerProtoZEgithub.com/polarismesh/specification/source/go/api/v1/fault_tolerance'
  _SOURCEMATCHER_LABELSENTRY._options = None
  _SOURCEMATCHER_LABELSENTRY._serialized_options = b'8\001'
  _DESTINATIONSET_METADATAENTRY._options = None
  _DESTINATIONSET_METADATAENTRY._serialized_options = b'8\001'
  _globals['_LEVEL']._serialized_start=5101
  _globals['_LEVEL']._serialized_end=5171
  _globals['_CIRCUITBREAKER']._serialized_start=106
  _globals['_CIRCUITBREAKER']._serialized_end=888
  _globals['_SOURCEMATCHER']._serialized_start=891
  _globals['_SOURCEMATCHER']._serialized_end=1113
  _globals['_SOURCEMATCHER_LABELSENTRY']._serialized_start=1051
  _globals['_SOURCEMATCHER_LABELSENTRY']._serialized_end=1113
  _globals['_RECOVERCONFIG']._serialized_start=1116
  _globals['_RECOVERCONFIG']._serialized_end=1551
  _globals['_RECOVERCONFIG_OUTLIERDETECTWHEN']._serialized_start=1493
  _globals['_RECOVERCONFIG_OUTLIERDETECTWHEN']._serialized_end=1551
  _globals['_CBPOLICY']._serialized_start=1554
  _globals['_CBPOLICY']._serialized_end=2763
  _globals['_CBPOLICY_ERRRATECONFIG']._serialized_start=1825
  _globals['_CBPOLICY_ERRRATECONFIG']._serialized_end=2347
  _globals['_CBPOLICY_ERRRATECONFIG_SPECIALCONFIG']._serialized_start=2124
  _globals['_CBPOLICY_ERRRATECONFIG_SPECIALCONFIG']._serialized_end=2347
  _globals['_CBPOLICY_SLOWRATECONFIG']._serialized_start=2350
  _globals['_CBPOLICY_SLOWRATECONFIG']._serialized_end=2565
  _globals['_CBPOLICY_CONSECUTIVEERRCONFIG']._serialized_start=2568
  _globals['_CBPOLICY_CONSECUTIVEERRCONFIG']._serialized_end=2763
  _globals['_DESTINATIONSET']._serialized_start=2766
  _globals['_DESTINATIONSET']._serialized_end=3526
  _globals['_DESTINATIONSET_METADATAENTRY']._serialized_start=3362
  _globals['_DESTINATIONSET_METADATAENTRY']._serialized_end=3426
  _globals['_DESTINATIONSET_RESOURCE']._serialized_start=3428
  _globals['_DESTINATIONSET_RESOURCE']._serialized_end=3464
  _globals['_DESTINATIONSET_TYPE']._serialized_start=3466
  _globals['_DESTINATIONSET_TYPE']._serialized_end=3495
  _globals['_DESTINATIONSET_SCOPE']._serialized_start=3497
  _globals['_DESTINATIONSET_SCOPE']._serialized_end=3526
  _globals['_CBRULE']._serialized_start=3528
  _globals['_CBRULE']._serialized_end=3614
  _globals['_RULEMATCHER']._serialized_start=3617
  _globals['_RULEMATCHER']._serialized_end=3878
  _globals['_RULEMATCHER_SOURCESERVICE']._serialized_start=3736
  _globals['_RULEMATCHER_SOURCESERVICE']._serialized_end=3787
  _globals['_RULEMATCHER_DESTINATIONSERVICE']._serialized_start=3789
  _globals['_RULEMATCHER_DESTINATIONSERVICE']._serialized_end=3878
  _globals['_CIRCUITBREAKERRULE']._serialized_start=3881
  _globals['_CIRCUITBREAKERRULE']._serialized_end=4384
  _globals['_ERRORCONDITION']._serialized_start=4387
  _globals['_ERRORCONDITION']._serialized_end=4540
  _globals['_ERRORCONDITION_INPUTTYPE']._serialized_start=4491
  _globals['_ERRORCONDITION_INPUTTYPE']._serialized_end=4540
  _globals['_TRIGGERCONDITION']._serialized_start=4543
  _globals['_TRIGGERCONDITION']._serialized_end=4771
  _globals['_TRIGGERCONDITION_TRIGGERTYPE']._serialized_start=4706
  _globals['_TRIGGERCONDITION_TRIGGERTYPE']._serialized_end=4771
  _globals['_RECOVERCONDITION']._serialized_start=4773
  _globals['_RECOVERCONDITION']._serialized_end=4841
  _globals['_FAULTDETECTCONFIG']._serialized_start=4843
  _globals['_FAULTDETECTCONFIG']._serialized_end=4878
  _globals['_FALLBACKCONFIG']._serialized_start=4880
  _globals['_FALLBACKCONFIG']._serialized_end=4952
  _globals['_FALLBACKRESPONSE']._serialized_start=4955
  _globals['_FALLBACKRESPONSE']._serialized_end=5099
  _globals['_FALLBACKRESPONSE_MESSAGEHEADER']._serialized_start=5056
  _globals['_FALLBACKRESPONSE_MESSAGEHEADER']._serialized_end=5099
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ontract.proto\x12\x02v1\"\xf0\x01\n\x0fServiceContract\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12+\n\ninterfaces\x18\t \x03(\x0b\x32\x17.v1.InterfaceDescriptor\x12\r\n\x05\x63time\x18\n \x01(\t\x12\r\n\x05mtime\x18\x0b \x01(\t\x12\x0e\n\x06status\x18\x0c \x01(\t\"\xdf\x01\n\x13InterfaceDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12.\n\x06source\x18\x05 \x01(\x0e\x32\x1e.v1.InterfaceDescriptor.Source\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\"-\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06Manual\x10\x01\x12\n\n\x06\x43lient\x10\x02\x42\x95\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x14ServiceContractProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\024ServiceContractProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_SERVICECONTRACT']._serialized_start=23
  _globals['_SERVICECONTRACT']._serialized_end=263
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=266
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=489
  _globals['_INTERFACEDESCRIPTOR_SOURCE']._serialized_start=444
  _globals['_INTERFACEDESCRIPTOR_SOURCE']._serialized_end=489
# @@protoc_insertion_point(module_scope)



from ..service_manage import service_pb2 as _service_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DiscoverFilter(_message.Message):
    __slots__ = ["OnlyHealthyInstance"]
    ONLYHEALTHYINSTANCE_FIELD_NUMBER: _ClassVar[int]
    OnlyHealthyInstance: bool
    def __init__(self, OnlyHealthyInstance: bool = ...) -> None: ...

class DiscoverRequest(_message.Message):
    __slots__ = ["type", "service", "Filter"]
    class DiscoverRequestType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNKNOWN: _ClassVar[DiscoverRequest.DiscoverRequestType]
        INSTANCE: _ClassVar[DiscoverRequest.DiscoverRequestType]
        CLUSTER: _ClassVar[DiscoverRequest.DiscoverRequestType]
        ROUTING: _ClassVar[DiscoverRequest.DiscoverRequestType]
        RATE_LIMIT: _ClassVar[DiscoverRequest.DiscoverRequestType]
        CIRCUIT_BREAKER: _ClassVar[DiscoverRequest.DiscoverRequestType]
        SERVICES: _ClassVar[DiscoverRequest.DiscoverRequestType]
        NAMESPACES: _ClassVar[DiscoverRequest.DiscoverRequestType]
        FAULT_DETECTOR: _ClassVar[DiscoverRequest.DiscoverRequestType]
        SERVICE_CONTRACT: _ClassVar[DiscoverRequest.DiscoverRequestType]
    UNKNOWN: DiscoverRequest.DiscoverRequestType
    INSTANCE: DiscoverRequest.DiscoverRequestType
    CLUSTER: DiscoverRequest.DiscoverRequestType
    ROUTING: DiscoverRequest.DiscoverRequestType
    RATE_LIMIT: DiscoverRequest.DiscoverRequestType
    CIRCUIT_BREAKER: DiscoverRequest.DiscoverRequestType
    SERVICES: DiscoverRequest.DiscoverRequestType
    NAMESPACES: DiscoverRequest.DiscoverRequestType
    FAULT_DETECTOR: DiscoverRequest.DiscoverRequestType
    SERVICE_CONTRACT: DiscoverRequest.DiscoverRequestType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    type: DiscoverRequest.DiscoverRequestType
    service: _service_pb2.Service
    Filter: DiscoverFilter
    def __init__(self, type: _Optional[_Union[DiscoverRequest.DiscoverRequestType, str]] = ..., service: _Optional[_Union[_service_pb2.Service, _Mapping]] = ..., Filter: _Optional[_Union[DiscoverFilter, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import service_pb2 as service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fheartbeat.proto\x12\x02v1\x1a\rservice.proto\"|\n\x0fHeartbeatRecord\x12\x1f\n\ninstanceId\x18\x01 \x01(\tR\x0binstance_id\x12,\n\x10lastHeartbeatSec\x18\x06 \x01(\x03R\x12last_heartbeat_sec\x12\x14\n\x05\x65xist\x18\x07 \x01(\x08R\x05\x65xistJ\x04\x08\x02\x10\x06\"\x94\x01\n\x11InstanceHeartbeat\x12\x1f\n\ninstanceId\x18\x01 \x01(\tR\x0binstance_id\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x12\n\x04host\x18\x04 \x01(\tR\x04host\x12\x12\n\x04port\x18\x05 \x01(\rR\x04port\"J\n\x11HeartbeatsRequest\x12\x35\n\nheartbeats\x18\x01 \x03(\x0b\x32\x15.v1.InstanceHeartbeatR\nheartbeats\"\x14\n\x12HeartbeatsResponse\"9\n\x14GetHeartbeatsRequest\x12!\n\x0binstanceIds\x18\x01 \x03(\tR\x0cinstance_ids\"F\n\x15GetHeartbeatsResponse\x12-\n\x07records\x18\x01 \x03(\x0b\x32\x13.v1.HeartbeatRecordR\x07records\"9\n\x14\x44\x65lHeartbeatsRequest\x12!\n\x0binstanceIds\x18\x01 \x03(\tR\x0cinstance_ids\"3\n\x15\x44\x65lHeartbeatsResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04info\x18\x02 \x01(\tB\x7f\n7com.tencent.polaris.specification.api.v1.service.manageZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_HEARTBEATRECORD']._serialized_start=38
  _globals['_HEARTBEATRECORD']._serialized_end=162
  _globals['_INSTANCEHEARTBEAT']._serialized_start=165
  _globals['_INSTANCEHEARTBEAT']._serialized_end=313
  _globals['_HEARTBEATSREQUEST']._serialized_start=315
  _globals['_HEARTBEATSREQUEST']._serialized_end=389
  _globals['_HEARTBEATSRESPONSE']._serialized_start=391
  _globals['_HEARTBEATSRESPONSE']._serialized_end=411
  _globals['_GETHEARTBEATSREQUEST']._serialized_start=413
  _globals['_GETHEARTBEATSREQUEST']._serialized_end=470
  _globals['_GETHEARTBEATSRESPONSE']._serialized_start=472
  _globals['_GETHEARTBEATSRESPONSE']._serialized_end=542
  _globals['_DELHEARTBEATSREQUEST']._serialized_start=544
  _globals['_DELHEARTBEATSREQUEST']._serialized_end=601
  _globals['_DELHEARTBEATSRESPONSE']._serialized_start=603
  _globals['_DELHEARTBEATSRESPONSE']._serialized_end=654
# @@protoc_insertion_point(module_scope)
